@@ -6,6 +6,7 @@ import json
 import os
 import shutil
 from collections import defaultdict
+from typing import DefaultDict
 
 import pylogconf.core
 import yaml
@@ -28,7 +29,7 @@ from pycmdtools.utils import yield_bad_symlinks, diamond_lines, checksum, downlo
         ConfigUseStandardExceptions
     ],
 )
-def find_bad_symlinks() -> None:
+def symlinks_find_bad() -> None:
     for full in yield_bad_symlinks(
         folder=ConfigFolder.folder,
         use_standard_exceptions=ConfigUseStandardExceptions.use_standard_exceptions,
@@ -87,7 +88,7 @@ def change_first_line() -> None:
     allow_free_args=True
 )
 def line_value_histogram() -> None:
-    saw = defaultdict(int)
+    saw: DefaultDict[str, int] = defaultdict(int)
     for line in diamond_lines(get_free_args()):
         line = line.rstrip()
         saw[line] += 1
@@ -237,16 +238,19 @@ def mcmp() -> None:
         if len(d.keys()) > 1:
             print(ConfigOutput.print)
     if ConfigCopy.copy:
-        sorted_keys = sorted(d.keys())
-        index_from = int(input("From what version? "))
-        index_to = int(input("To what version? "))
-        checksum_from = sorted_keys[index_from]
-        checksum_to = sorted_keys[index_to]
-        set_from = d[checksum_from]
-        set_to = d[checksum_to]
-        source_file = set_from.pop()
-        for target_file in set_to:
-            shutil.copy(source_file, target_file)
+        if len(d.keys()) > 1:
+            sorted_keys = sorted(d.keys())
+            index_from = int(input("From what version? "))
+            index_to = int(input("To what version? "))
+            checksum_from = sorted_keys[index_from]
+            checksum_to = sorted_keys[index_to]
+            set_from = d[checksum_from]
+            set_to = d[checksum_to]
+            source_file = set_from.pop()
+            for target_file in set_to:
+                shutil.copy(source_file, target_file)
+        else:
+            print("All copies are identical, cannot copy")
 
 
 @register_endpoint(
@@ -287,13 +291,15 @@ def google_drive_download_by_url() -> None:
 )
 def extension_stats():
     counter = collections.Counter()
-    for filename in os.listdir():
+    for filename in get_free_args():
         _, extension = os.path.splitext(filename)
         if len(extension) >= 1 and extension[0] == ".":
             extension = extension[1:]
         counter.update([extension])
     # pretty print the counter object
     total = 0
+    # most common returns all elements if not passed a value,
+    # sorted in value order with highest first
     for value, count in counter.most_common():
         print(f"{value} {count}")
         total += count
